function drawProjectedMesh(mesh,P, h_parent)
%% This function draws a projected mesh overlay over an image
%projectMPI08Coordinates projects 3D coordinates X to camera pixels of
%   INPUT:
%     X: 3xN coordinates of N points, or 4xN homogeneous coordinates
%     P: projection matrix (translation in meters!)
%   OUTPUT:
%     2xN image coordinates
%
% This function is part of the MPI08 data set, to be obtained at 
% http://www.tnt.uni-hannover.de/project/MPI08_Database/
%
%
% Written by: Gerard Pons 
% Revision:   1.0
% Date:       01.10.2010
%
% Copyright 2010, MPI Informatik, Germany, and Hannover University, Germany.
% All Rights Reserved Permission to use, copy, modify, and distribute this
% software and its documentation for any non-commercial purpose is hereby
% granted without fee, provided that the above copyright notice appear in
% all copies and that both that copyright notice and this permission
% notice appear in supporting documentation, and that the name of the
% author not be used in advertising or publicity pertaining to distribution
% of the software without specific, written prior permission.
% THE AUTHOR DISCLAIMS ALL WARRANTIES WITH REGARD TO THIS SOFTWARE,
% INCLUDING ALL IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR ANY
% PARTICULAR PURPOSE. IN NO EVENT SHALL THE AUTHOR BE LIABLE FOR ANY
% SPECIAL, INDIRECT OR CONSEQUENTIAL DAMAGES OR ANY DAMAGES WHATSOEVER
% RESULTING FROM LOSS OF USE, DATA OR PROFITS, WHETHER IN AN ACTION OF
% CONTRACT, NEGLIGENCE OR OTHER TORTIOUS ACTION, ARISING OUT OF OR IN
% CONNECTION WITH THE USE OR PERFORMANCE OF THIS SOFTWARE.

proj_mesh=mesh;
vertices = imageProjection(mesh.vertices,P)';
proj_mesh.vertices=vertices;
faces = mesh.faces';
for j=1:length(mesh.skel.nodes)
    proj_mesh.skel.nodes(j).position=imageProjection(mesh.skel.nodes(j).position,P);
end
p=patch('Parent',h_parent,'Faces', faces, 'Vertices', vertices, 'FaceVertexCData', repmat([1 1 0], size(vertices, 1), 1), 'FaceColor', 'interp', 'EdgeColor', [0.75 0.75 0]);
set(p, 'faceAlpha', 0.9);
set(p, 'edgeAlpha', 0.2);
set(p, 'ambientStrength', 0.4);
set(p, 'diffuseStrength', 0.4);
set(p, 'BackFaceLighting', 'unlit')
set(p, 'FaceLighting', 'phong');
set(p, 'edgeLighting', 'phong');
hold on;
if (isfield(proj_mesh, 'skel'))
    % draw a skeleton inside
    nodes = proj_mesh.skel.nodes;
    [skelVertices, skelFaces] = generateSkeletonPatch(nodes);
    numVertices = size(skelVertices, 2);
    skelp=patch('Parent',h_parent,'Faces', skelFaces', 'Vertices', skelVertices', 'FaceVertexCData', repmat([1 0 0],numVertices, 1), 'FaceColor', 'flat', 'EdgeColor', 'flat');
    set(skelp, 'marker', '.', 'markersize', 25);
    set(skelp, 'edgeLighting', 'none');
    set(skelp, 'edgeAlpha', 0.3);  %0.3
    set(skelp, 'faceLighting', 'none');
    set(skelp, 'lineWidth', 3);
end
end
